
This is a fork from the original repo:https://github.com/Abe404/RootPainter3D
The purpose of this fork is to extend the rootpainter3d to use DICOM files.
Additionally, we might change the preprocessing pipeline to include data augmentations
